Index: /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/Makefile
===================================================================
--- /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/Makefile	(revision 323)
+++ /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/Makefile	(revision 324)
@@ -1,1 +1,2 @@
 include ../Makefile.inc
+CFLAGS+= -DINTERRUPT_DELAY=${INTERRUPT_DELAY}
Index: /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/run
===================================================================
--- /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/run	(revision 323)
+++ /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/run	(revision 324)
@@ -18,16 +18,19 @@
 }
 
-make --quiet || exit 1
-${SIMUL} > run.out 2>&1 
-if [ $? -eq 0 ]; then
-	if check_output; then
-		echo "test passsed";
-		make --quiet clean
-		exit 0;
+
+for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70; do
+	make clean --quiet
+	make INTERRUPT_DELAY=$i --quiet || exit 1
+    ${SIMUL} > run.out 2>&1 
+	if [ $? -eq 0 ]; then
+		if check_output; then
+			echo "test $i passed";
+			make --quiet clean
+		    exit 0;
+		fi
+	else
+		echo "test FAILED"
+		exit 1
 	fi
-	echo "test FAILED"
-	exit 1
-fi
+done
 echo "test FAILED"
-exit 1
-
Index: /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/test.S
===================================================================
--- /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/test.S	(revision 323)
+++ /trunk/softs/tests_ccvcache_v4/test_interrupt_delayslot/test.S	(revision 324)
@@ -28,8 +28,10 @@
 	li	s0, MAGIC2
 	/*
 	 * interrupt in 42 cycles.
 	 * Without cache this takes us to the delay slot of the jump.
 	 */
-	li	a0, 42
+
+	li	a0, INTERRUPT_DELAY
+	//li	a0, 38
 	sw	a0, XICU_PTI_PER(0)(t0)
 	/* clear pending interrupt */
@@ -28,8 +28,10 @@
 	li	s0, MAGIC2
 	/*
-	 * interrupt in 42 cycles.
+	 * interrupt in INTERRUPT_DELAY cycles.
 	 * Without cache this takes us to the delay slot of the jump.
 	 */
